@@ -146,10 +146,14 @@ void XbmcConnectionPrivate::sendNextCommand()
         }
 
         QJson::Serializer serializer;
+        QByteArray data = serializer.serialize(map);
+        qDebug() << "ater serializing:" << data;
+        QString dataStr = QString::fromLatin1(data);
 #ifdef DEBUGJSON
-        qDebug() << "sending command" << serializer.serialize(map);
+        qDebug() << "sending command 1" << dataStr;
+        qDebug() << "sending command 2" << dataStr.toLocal8Bit();
 #endif
-        m_socket->write(serializer.serialize(map));
+        m_socket->write(data);
         m_currentPendingId = command.id();
         m_timeoutTimer.start();
     }
@@ -189,7 +193,7 @@ void XbmcConnectionPrivate::readData()
 //        qDebug() << "starting parsing";
         QJson::Parser parser;
         bool ok;
-        rsp = parser.parse(lineData.toLocal8Bit(), &ok).toMap();
+        rsp = parser.parse(lineData.toAscii(), &ok).toMap();
         if(!ok) {
             qDebug() << "data is" << lineData;
             qFatal("failed parsing.");
